==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/hole/dialogs_de.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")
dialogStr("Hier spukt es.")

dialogId("v-bojim", "font_big",
        "I fear it will be dificult to move things over this hole.")
dialogStr("Ich glaube, es wird schwierig, Dinge über diesen Graben zu bewegen.")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")
dialogStr("Bitte, wie Sie wünschen.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")
dialogStr("Ist da jemand?")

dialogId("l-halo1", "font_lightgrey", "Who are there?")
dialogStr("Wer ist dort?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")
dialogStr("Ich glaube, der Telefonhörer funktioniert nicht.")

dialogId("l-dejte0", "font_lightgrey",
         "Put it back immediately, the indian headdress is mine.")
dialogStr("Gib das sofort zurück! Der Federschmuck gehört mir.")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")
dialogStr("Gib das sofort zurück, das gehört mir!")

dialogId("l-dejte2", "font_lightgrey",
         "O O O O, I am indian. Put it back immediately!")
dialogStr("Oehoehoehoe, ich bin ein Indianer! Gib das sofort zurück!")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")
dialogStr("Oehoehoehoe. Gib das sofort zurück!")

dialogId("l-vinnetou", "font_lightgrey",
         "Where are you pushing me? I am famous Vinnetou!")
dialogStr("Wohin schubst du mich? Ich bin der berühmte Winnetou!")

dialogId("m-nedame0", "font_small",
         "Sorry, we need it necessarily.")
dialogStr("Entschuldige, wir brauchen das dringend.")

dialogId("v-nedame0", "font_big",
        "How can it be yours, if you are not indian?")
dialogStr("Wie kann das dir gehören, wenn du kein Indianer bist?")

dialogId("m-nedame1", "font_small",
         "You can't be indian because you are not red?")
dialogStr("Du kannst kein Indianer sein, du bist nicht rot.")

dialogId("v-nedame1", "font_big", "I can't demur anything.")
dialogStr("Ich streite nichts ab.")

dialogId("v-neber", "font_big",
"Player, if you are an indian, don't perceive as an discrimination please.")
dialogStr("Spieler, wenn du ein Indianer bist, betrachte das bitte nicht als Diskriminierung.")

dialogId("m-sluchatko", "font_small", "It may be magic receiver.")
dialogStr("Vielleicht ist es ein magischer Telefonhörer.")

dialogId("v-zkus", "font_big", "Try it.")
dialogStr("Versuch es.")

dialogId("m-zmizet", "font_small",
         "Hello, I wish to disappear the steel near exit?")
dialogStr("Hallo, ich wünsche mir, dass der Stahl am Ausgang verschwindet.")

dialogId("v-vratte", "font_big",
         "Put it back, it should be solved by player, not by ourself.")
dialogStr("Leg ihn zurück! Das sollte vom Spieler gelöst werden, nicht von uns.")

==> fillets-ng-data_0.9.0.orig.tar.gz: fillets-ng-data-0.9.0/script/hole/dialogs_de.lua <==
dialogId("m-strasidelna", "font_small", "It is a haunted room.")
dialogStr("Hier spukt es.")

dialogId("v-bojim", "font_big",
        "I fear it will be dificult to move things over this hole.")
dialogStr("Ich glaube, es wird schwierig, Dinge über diesen Graben zu bewegen.")

dialogId("s-prejete", "font_green", "Here you are, as you wish.")
dialogStr("Bitte, wie Sie wünschen.")

dialogId("l-halo0", "font_lightgrey", "Is anybody there?")
dialogStr("Ist da jemand?")

dialogId("l-halo1", "font_lightgrey", "Who are there?")
dialogStr("Wer ist dort?")

dialogId("l-halo2", "font_lightgrey", "I think, the receiver does not work.")
dialogStr("Ich glaube, der Telefonhörer funktioniert nicht.")

dialogId("l-dejte0", "font_lightgrey",
         "Put it back immediately, the indian headdress is mine.")
dialogStr("Gib das sofort zurück! Der Federschmuck gehört mir.")

dialogId("l-dejte1", "font_lightgrey", "Put it back immediately, it is mine!")
dialogStr("Gib das sofort zurück, das gehört mir!")

dialogId("l-dejte2", "font_lightgrey",
         "O O O O, I am indian. Put it back immediately!")
dialogStr("Oehoehoehoe, ich bin ein Indianer! Gib das sofort zurück!")

dialogId("l-dejte3", "font_lightgrey", "O O O O, put it back immediately!")
dialogStr("Oehoehoehoe. Gib das sofort zurück!")

dialogId("l-vinnetou", "font_lightgrey",
         "Where are you pushing me? I am famous Vinnetou!")
dialogStr("Wohin schubst du mich? Ich bin der berühmte Winnetou!")

dialogId("m-nedame0", "font_small",
         "Sorry, we need it necessarily.")
dialogStr("Entschuldige, wir brauchen das dringend.")

dialogId("v-nedame0", "font_big",
        "How can it be yours, if you are not indian?")
dialogStr("Wie kann das dir gehören, wenn du kein Indianer bist?")

dialogId("m-nedame1", "font_small", "You can’t be indian because you are not red?")
dialogStr("Du kannst kein Indianer sein, du bist nicht rot.")

dialogId("v-nedame1", "font_big", "I can’t demur anything.")
dialogStr("Ich streite nichts ab.")

dialogId("v-neber", "font_big", "Player, if you are an indian, don’t perceive as an discrimination please.")
dialogStr("Spieler, wenn du ein Indianer bist, betrachte das bitte nicht als Diskriminierung.")

dialogId("m-sluchatko", "font_small", "It may be magic receiver.")
dialogStr("Vielleicht ist es ein magischer Telefonhörer.")

dialogId("v-zkus", "font_big", "Try it.")
dialogStr("Versuch es.")

dialogId("m-zmizet", "font_small",
         "Hello, I wish to disappear the steel near exit?")
dialogStr("Hallo, ich wünsche mir, dass der Stahl am Ausgang verschwindet.")

dialogId("v-vratte", "font_big",
         "Put it back, it should be solved by player, not by ourself.")
dialogStr("Leg ihn zurück! Das sollte vom Spieler gelöst werden, nicht von uns.")
